[113701] Rename Environment to IEnvironment.
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentException.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentException.java
index b9f90e9..5cc3c59 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentException.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentException.java
@@ -13,7 +13,7 @@
 import org.eclipse.core.runtime.IStatus;
 
 /**
- * This is the exception class for conditions raised by the Environment.
+ * This is the exception class for conditions raised by the IEnvironment.
  */
 public class EnvironmentException extends Exception
 {
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentService.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentService.java
index cf4e065..67e925e 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentService.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/EnvironmentService.java
@@ -8,7 +8,7 @@
  **************************************************************************************************/
 package org.eclipse.wst.common.environment;
 
-import org.eclipse.wst.common.environment.uri.URIScheme;
+import org.eclipse.wst.common.environment.uri.IURIScheme;
 import org.eclipse.wst.common.internal.environment.eclipse.ConsoleEclipseEnvironment;
 import org.eclipse.wst.common.internal.environment.eclipse.EclipseLog;
 import org.eclipse.wst.common.internal.environment.eclipse.EclipseScheme;
@@ -16,22 +16,22 @@
 
 public class EnvironmentService
 {
-  public static Environment getEclipseConsoleEnvironment()
+  public static IEnvironment getEclipseConsoleEnvironment()
   {
     return new ConsoleEclipseEnvironment(); 
   }  
   
-  public static Log getEclipseLog()
+  public static ILog getEclipseLog()
   {
     return new EclipseLog();
   }
   
-  public static URIScheme getEclipseScheme( Environment environment )
+  public static IURIScheme getEclipseScheme( IEnvironment environment )
   {
     return new EclipseScheme( environment );
   }  
   
-  public static URIScheme getFileScheme()
+  public static IURIScheme getFileScheme()
   {
     return new FileScheme();   
   }
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/StatusHandler.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/IStatusHandler.java
similarity index 97%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/StatusHandler.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/IStatusHandler.java
index bc9c812..f6165a7 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/StatusHandler.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/IStatusHandler.java
@@ -18,7 +18,7 @@
  * may raise an exception against the caller to have them abort
  * procesing.
  */
-public interface StatusHandler
+public interface IStatusHandler
 {
   /**
    * Reports the given Status and set of possible responses.
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/NullStatusHandler.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/NullStatusHandler.java
index 80ca93b..349aac3 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/NullStatusHandler.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/NullStatusHandler.java
@@ -12,11 +12,11 @@
 
 import org.eclipse.core.runtime.IStatus;
 
-public class NullStatusHandler implements StatusHandler
+public class NullStatusHandler implements IStatusHandler
 {
   
   /**
-   * @see org.eclipse.env.common.StatusHandler#report(org.eclipse.env.common.Status, org.eclipse.env.common.Choice[])
+   * @see org.eclipse.env.common.IStatusHandler#report(org.eclipse.env.common.Status, org.eclipse.env.common.Choice[])
    */
   public Choice report(IStatus status, Choice[] choices) 
   {
@@ -32,7 +32,7 @@
   }
 
   /**
-   * @see org.eclipse.env.common.StatusHandler#report(org.eclipse.env.common.Status)
+   * @see org.eclipse.env.common.IStatusHandler#report(org.eclipse.env.common.Status)
    */
   public void report(IStatus status) throws StatusException
   {
@@ -47,7 +47,7 @@
   }
   
   /**
-   * @see org.eclipse.wst.common.environment.StatusHandler#reportError(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
+   * @see org.eclipse.wst.common.environment.IStatusHandler#reportError(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
    */
   public void reportError(IStatus status)
   {
@@ -55,7 +55,7 @@
   }
   
   /**
-   * @see org.eclipse.wst.common.environment.StatusHandler#reportInfo(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
+   * @see org.eclipse.wst.common.environment.IStatusHandler#reportInfo(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
    */
   public void reportInfo(IStatus status)
   {
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeScheme.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeScheme.java
index 6e85e29..ea50179 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeScheme.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeScheme.java
@@ -15,7 +15,7 @@
 import org.eclipse.core.runtime.Status;
 
 
-public class RelativeScheme implements URIScheme
+public class RelativeScheme implements IURIScheme
 {
 
   /* (non-Javadoc)
@@ -29,7 +29,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#isValid(org.eclipse.env.uri.URI)
    */
-  public boolean isValid(URI uri)
+  public boolean isValid(IURI uri)
   {
     return !uri.toString().startsWith( "/" );
   }
@@ -37,7 +37,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#newURI(java.lang.String)
    */
-  public URI newURI(String uri) 
+  public IURI newURI(String uri) 
   {
     return new RelativeURI( uri );
   }
@@ -45,7 +45,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#newURI(org.eclipse.env.uri.URI)
    */
-  public URI newURI(URI uri) 
+  public IURI newURI(IURI uri) 
   {
     return new RelativeURI( uri.toString() );
   }
@@ -53,7 +53,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#newURI(java.net.URL)
    */
-  public URI newURI(URL url) 
+  public IURI newURI(URL url) 
   {
     return new RelativeURI( url.toString() );
   }
@@ -61,7 +61,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#validate(org.eclipse.env.uri.URI)
    */
-  public IStatus validate(URI uri)
+  public IStatus validate(IURI uri)
   {
     IStatus result = null;
     
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeURI.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeURI.java
index a4516d0..8b06c27 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeURI.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/RelativeURI.java
@@ -21,7 +21,7 @@
 import org.eclipse.wst.common.internal.environment.eclipse.Messages;
 
 
-public class RelativeURI implements URI
+public class RelativeURI implements IURI
 {
   protected String uri_;
   
@@ -33,7 +33,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#append(org.eclipse.env.uri.URI)
    */
-  public URI append(URI relativeURI) throws URIException
+  public IURI append(IURI relativeURI) throws URIException
   {
     if( !relativeURI.isRelative()) 
      {      
@@ -117,7 +117,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#getURIScheme()
    */
-  public URIScheme getURIScheme()
+  public IURIScheme getURIScheme()
   {
     return new RelativeScheme();
   }
@@ -189,23 +189,23 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#list()
    */
-  public URI[] list() throws URIException
+  public IURI[] list() throws URIException
   {
-    return new URI[0];
+    return new IURI[0];
   }
 
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#list(org.eclipse.env.uri.URIFilter)
    */
-  public URI[] list(URIFilter uriFilter) throws URIException
+  public IURI[] list(IURIFilter uriFilter) throws URIException
   {
-    return new URI[0];
+    return new IURI[0];
   }
 
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#parent()
    */
-  public URI parent() throws URIException
+  public IURI parent() throws URIException
   {
     int lastSlash  = uri_.lastIndexOf( '/' );
     int firstSlash = uri_.indexOf( '/' );
@@ -220,7 +220,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#rename(org.eclipse.env.uri.URI)
    */
-  public void rename(URI newURI) throws URIException
+  public void rename(IURI newURI) throws URIException
   {
     uri_ = newURI.toString();
   }
@@ -242,7 +242,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#visit(org.eclipse.env.uri.URIVisitor, org.eclipse.env.uri.URIFilter)
    */
-  public void visit(URIVisitor uriVisitor, URIFilter uriFilter)
+  public void visit(IURIVisitor uriVisitor, IURIFilter uriFilter)
     throws URIException
   {
     boolean continueVisit = true;
@@ -253,7 +253,7 @@
       continueVisit = uriVisitor.visit( this );  
     }
        
-    URI[] children  = list();
+    IURI[] children  = list();
     
     for( int index = 0; index < children.length && continueVisit; index++ )
     {
@@ -264,11 +264,11 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#visit(org.eclipse.env.uri.URIVisitor)
    */
-  public void visit(URIVisitor uriVisitor) throws URIException
+  public void visit(IURIVisitor uriVisitor) throws URIException
   {
     boolean continueVisit = uriVisitor.visit( this );  
     
-    URI[] children  = list();
+    IURI[] children  = list();
     
     for( int index = 0; index < children.length && continueVisit; index++ )
      {
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/ConsoleEclipseEnvironment.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/ConsoleEclipseEnvironment.java
index 9b155ea..1c6b5cb 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/ConsoleEclipseEnvironment.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/ConsoleEclipseEnvironment.java
@@ -10,29 +10,29 @@
  *******************************************************************************/
 package org.eclipse.wst.common.internal.environment.eclipse;
 
-import org.eclipse.wst.common.environment.Environment;
-import org.eclipse.wst.common.environment.Log;
+import org.eclipse.wst.common.environment.IEnvironment;
+import org.eclipse.wst.common.environment.ILog;
 import org.eclipse.wst.common.environment.NullStatusHandler;
-import org.eclipse.wst.common.environment.StatusHandler;
+import org.eclipse.wst.common.environment.IStatusHandler;
 import org.eclipse.wst.common.environment.uri.SimpleURIFactory;
-import org.eclipse.wst.common.environment.uri.URIFactory;
+import org.eclipse.wst.common.environment.uri.IURIFactory;
 import org.eclipse.wst.common.internal.environment.uri.file.FileScheme;
 
 
 /**
  *  This class is intended for use in a headless Eclipse environment.  
  */
-public class ConsoleEclipseEnvironment implements Environment
+public class ConsoleEclipseEnvironment implements IEnvironment
 {
 	private SimpleURIFactory  uriFactory_      = null;
-	private StatusHandler     statusHandler_   = null;
+	private IStatusHandler     statusHandler_   = null;
 	  
 	public ConsoleEclipseEnvironment()
 	{
 	  this( new NullStatusHandler() );	
 	}
 	
-	public ConsoleEclipseEnvironment( StatusHandler  statusHandler )
+	public ConsoleEclipseEnvironment( IStatusHandler  statusHandler )
 	{
 	  uriFactory_      = new SimpleURIFactory();
 	  statusHandler_   = statusHandler;
@@ -44,7 +44,7 @@
 	/* (non-Javadoc)
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Environment#getLog()
 	 */
-	public Log getLog() 
+	public ILog getLog() 
 	{
 		return new EclipseLog();
 	}
@@ -52,7 +52,7 @@
 	/* (non-Javadoc)
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Environment#getStatusHandler()
 	 */
-	public StatusHandler getStatusHandler() 
+	public IStatusHandler getStatusHandler() 
 	{
 		return statusHandler_;
 	}
@@ -60,7 +60,7 @@
 	/* (non-Javadoc)
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Environment#getURIFactory()
 	 */
-	public URIFactory getURIFactory() 
+	public IURIFactory getURIFactory() 
 	{
 		return uriFactory_;
 	}
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceOutputStream.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceOutputStream.java
index 6129f89..d1a21f1 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceOutputStream.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceOutputStream.java
@@ -16,7 +16,7 @@
 import java.io.OutputStream;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
-import org.eclipse.wst.common.environment.StatusHandler;
+import org.eclipse.wst.common.environment.IStatusHandler;
 
 
 
@@ -28,7 +28,7 @@
 {
 
   IPath                 fFilePath;
-  StatusHandler         fStatusHandler;
+  IStatusHandler         fStatusHandler;
   ByteArrayOutputStream fByteArrayOutputStream;
   boolean               fOpen;
 
@@ -51,7 +51,7 @@
   */
   public FileResourceOutputStream ( 
   			IPath           filePath, 
-  			StatusHandler   statusHandler
+  			IStatusHandler   statusHandler
   			)
   {
     fFilePath = filePath;
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceUtils.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceUtils.java
index 70cc74c..cde954f 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceUtils.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/FileResourceUtils.java
@@ -32,7 +32,7 @@
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.wst.common.environment.Choice;
 import org.eclipse.wst.common.environment.StatusException;
-import org.eclipse.wst.common.environment.StatusHandler;
+import org.eclipse.wst.common.environment.IStatusHandler;
 
 
 
@@ -183,7 +183,7 @@
                                 IPath sourcePath,
                                 IPath pathname,
                                 IPath targetPath,
-                                StatusHandler statusMonitor )
+                                IStatusHandler statusMonitor )
      throws CoreException
    {
      try
@@ -211,7 +211,7 @@
    * @return True if the file does not exist or if it exists and is successfully deleted. False otherwise.
    */
   public static boolean deleteFile( IFile file,
-                                    StatusHandler statusMonitor)
+                                    IStatusHandler statusMonitor)
     throws CoreException
   {
     if (file.exists())
@@ -245,7 +245,7 @@
    * @return True if the folder does not exist or if it exists and is successfully deleted along with its members. False otherwise.
    */
    public static boolean deleteFolder( IFolder folder,
-                                       StatusHandler statusMonitor )
+                                       IStatusHandler statusMonitor )
      throws CoreException
    {
      if (!folder.exists()) return true;
@@ -297,7 +297,7 @@
   public static IFile createFile (
     IPath           absolutePath,
     InputStream     inputStream,
-    StatusHandler   statusHandler )
+    IStatusHandler   statusHandler )
 
     throws CoreException 
   {    
@@ -367,7 +367,7 @@
     IProject        project,
     IPath           relativePath,
     InputStream     inputStream,
-    StatusHandler   statusMonitor )
+    IStatusHandler   statusMonitor )
  
     throws CoreException 
   {
@@ -410,7 +410,7 @@
 
   public static OutputStream newFileOutputStream (
        IPath            file,
-       StatusHandler    statusHandler )
+       IStatusHandler    statusHandler )
  
   {
     return new FileResourceOutputStream(file, statusHandler);
@@ -435,7 +435,7 @@
    */
   public static IContainer makeFolderPath (
     IPath            absolutePath,
-    StatusHandler    statusHandler )
+    IStatusHandler    statusHandler )
   
     throws CoreException
   {
@@ -458,7 +458,7 @@
  private static IFolder makeFolder (
     IContainer       parent,
     String           folderName,
-    StatusHandler    statusHandler )
+    IStatusHandler    statusHandler )
   
   throws CoreException
   {
@@ -493,7 +493,7 @@
     IContainer       parent,
     String           fileName,
     InputStream      inputStream,
-    StatusHandler    statusHandler )
+    IStatusHandler    statusHandler )
  
     throws CoreException
   {
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileScheme.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileScheme.java
index 053f8e5..1c887f2 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileScheme.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileScheme.java
@@ -14,7 +14,7 @@
 
 import org.eclipse.wst.common.environment.uri.RelativeScheme;
 import org.eclipse.wst.common.environment.uri.RelativeURI;
-import org.eclipse.wst.common.environment.uri.URI;
+import org.eclipse.wst.common.environment.uri.IURI;
 
 
 public class FileScheme extends RelativeScheme 
@@ -22,7 +22,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#isValid(org.eclipse.env.uri.URI)
    */
-  public boolean isValid(URI uri)
+  public boolean isValid(IURI uri)
   {
     return uri.toString().startsWith( "file:" );
   }
@@ -30,7 +30,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#newURI(java.lang.String)
    */
-  public URI newURI(String uri) 
+  public IURI newURI(String uri) 
   {
     String newURI = null;
     
@@ -58,7 +58,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#newURI(org.eclipse.env.uri.URI)
    */
-  public URI newURI(URI uri) 
+  public IURI newURI(IURI uri) 
   {
     return new FileURI( uri.toString() );
   }
@@ -66,7 +66,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URIScheme#newURI(java.net.URL)
    */
-  public URI newURI(URL url) 
+  public IURI newURI(URL url) 
   {
     return new FileURI( url.toString() );
   }
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileURI.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileURI.java
index d767f79..abb1481 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileURI.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/uri/file/FileURI.java
@@ -20,10 +20,10 @@
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.wst.common.environment.uri.RelativeURI;
-import org.eclipse.wst.common.environment.uri.URI;
+import org.eclipse.wst.common.environment.uri.IURI;
 import org.eclipse.wst.common.environment.uri.URIException;
-import org.eclipse.wst.common.environment.uri.URIFilter;
-import org.eclipse.wst.common.environment.uri.URIScheme;
+import org.eclipse.wst.common.environment.uri.IURIFilter;
+import org.eclipse.wst.common.environment.uri.IURIScheme;
 
 
 public class FileURI extends RelativeURI 
@@ -127,7 +127,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#getURIScheme()
    */
-  public URIScheme getURIScheme()
+  public IURIScheme getURIScheme()
   {
     return new FileScheme();
   }
@@ -183,16 +183,16 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#list()
    */
-  public URI[] list() throws URIException
+  public IURI[] list() throws URIException
   {
     File[] children = file_.listFiles();
-    URI[]  URIs     = new URI[0];
+    IURI[]  URIs     = new IURI[0];
     
     if( children != null )
     {
       int   length   = children.length;
       
-      URIs = new URI[length];
+      URIs = new IURI[length];
     
       for( int index = 0; index < length; index++ )
       {
@@ -206,7 +206,7 @@
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#list(org.eclipse.env.uri.URIFilter)
    */
-  public URI[] list(URIFilter uriFilter) throws URIException
+  public IURI[] list(IURIFilter uriFilter) throws URIException
   {
     File[]   children = file_.listFiles();
     int      length   = children == null ? 0 : children.length;
@@ -214,7 +214,7 @@
     
     for( int index = 0; index < length; index++ )
     {
-      URI newURI = new FileURI( "file:" + children[index].getAbsolutePath() );
+      IURI newURI = new FileURI( "file:" + children[index].getAbsolutePath() );
       
       if( uriFilter.accepts( newURI) )
       {
@@ -222,13 +222,13 @@
       } 
     }
     
-    return (URI[])URIs.toArray( new URI[0] );
+    return (IURI[])URIs.toArray( new IURI[0] );
   }
 
   /* (non-Javadoc)
    * @see org.eclipse.env.uri.URI#rename(org.eclipse.env.uri.URI)
    */
-  public void rename(URI newURI) throws URIException
+  public void rename(IURI newURI) throws URIException
   {
     uri_ = newURI.toString();
     file_.renameTo( new File( uri_ ) );
diff --git a/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/datamodel/ui/DataModelWizard.java b/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/datamodel/ui/DataModelWizard.java
index 9e73fad..020b7a5 100644
--- a/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/datamodel/ui/DataModelWizard.java
+++ b/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/datamodel/ui/DataModelWizard.java
@@ -16,7 +16,7 @@
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.wizard.IWizardPage;
 import org.eclipse.jface.wizard.Wizard;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 import org.eclipse.wst.common.frameworks.datamodel.DataModelFactory;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModel;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModelOperation;
@@ -252,7 +252,7 @@
    * Creates the default environment for this wizard.
    * @return
    */
-  protected Environment createEnvironment()
+  protected IEnvironment createEnvironment()
   {
     return new EclipseEnvironment();
   }
diff --git a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/AbstractDataModelOperation.java b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/AbstractDataModelOperation.java
index 4f79dbb..6239458 100644
--- a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/AbstractDataModelOperation.java
+++ b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/AbstractDataModelOperation.java
@@ -20,7 +20,7 @@
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 
 /**
  * Abstract implementation for an IDataModelOperation.
@@ -37,7 +37,7 @@
 	protected static final IStatus OK_STATUS = IDataModelProvider.OK_STATUS;
 
 	private String id;
-	private Environment environment;
+	private IEnvironment environment;
 
 	/**
 	 * The IDataModel used by this IDataModelOperation
@@ -112,11 +112,11 @@
 		return IWorkspace.AVOID_UPDATE;
 	}
 
-	public void setEnvironment(Environment env) {
+	public void setEnvironment(IEnvironment env) {
 		environment = env;
 	}
 
-	public Environment getEnvironment() {
+	public IEnvironment getEnvironment() {
 		return environment;
 	}
 
diff --git a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/IDataModelOperation.java b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/IDataModelOperation.java
index 480fea2..b1fa268 100644
--- a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/IDataModelOperation.java
+++ b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/datamodel/IDataModelOperation.java
@@ -13,7 +13,7 @@
 import java.util.Set;
 import org.eclipse.core.commands.operations.IUndoableOperation;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 
 /**
  * <p>
@@ -71,5 +71,5 @@
 
 	public int getOperationExecutionFlags();
 
-  public void setEnvironment( Environment environment );
+  public void setEnvironment( IEnvironment environment );
 }
diff --git a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/OperationManager.java b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/OperationManager.java
index 53dc040..3065a33 100644
--- a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/OperationManager.java
+++ b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/OperationManager.java
@@ -23,7 +23,7 @@
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 import org.eclipse.wst.common.frameworks.datamodel.AbstractDataModelOperation;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModel;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModelOperation;
@@ -43,9 +43,9 @@
 	private OperationListener preExecuteListener;
 	private OperationListener postExecuteListener;
 	private OperationListener undoExecuteListener;
-  private Environment       environment;
+  private IEnvironment       environment;
 
-	public OperationManager(DataModelManager aDataModelManager, IDataModelOperation aRootOperation, Environment aEnvironment) {
+	public OperationManager(DataModelManager aDataModelManager, IDataModelOperation aRootOperation, IEnvironment aEnvironment) {
 		if (aRootOperation == null)
 			aRootOperation = new NullOperation();
 
diff --git a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/datamodel/ExtendableOperationImpl.java b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/datamodel/ExtendableOperationImpl.java
index 177709b..3859a39 100644
--- a/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/datamodel/ExtendableOperationImpl.java
+++ b/plugins/org.eclipse.wst.common.frameworks/src/org/eclipse/wst/common/frameworks/internal/datamodel/ExtendableOperationImpl.java
@@ -27,7 +27,7 @@
 import org.eclipse.core.runtime.SubProgressMonitor;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
 import org.eclipse.jem.util.logger.proxy.Logger;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModel;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModelOperation;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModelProperties;
@@ -42,7 +42,7 @@
 
 	private IDataModelOperation rootOperation;
 	private List appendedOperations;
-	private Environment environment;
+	private IEnvironment environment;
 
 	private OperationStatus opStatus;
 
@@ -311,11 +311,11 @@
 		return rootOperation.getDataModel();
 	}
 
-	public void setEnvironment(Environment env) {
+	public void setEnvironment(IEnvironment env) {
 		environment = env;
 	}
 
-	public Environment getEnvironment() {
+	public IEnvironment getEnvironment() {
 		return environment;
 	}
 }
\ No newline at end of file
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/Environment.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/IEnvironment.java
similarity index 76%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/Environment.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/IEnvironment.java
index ad260f8..3bd254a 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/Environment.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/IEnvironment.java
@@ -10,11 +10,11 @@
  *******************************************************************************/
 package org.eclipse.wst.common.environment;
 
-import org.eclipse.wst.common.environment.uri.URIFactory;
+import org.eclipse.wst.common.environment.uri.IURIFactory;
 
 
 /**
  * An Environment provides the means for a 
  * <ol>
  * <li>A log for writing messages to a logging facility,</li>
  * <li>A progress monitor for receiving progress information,</li>
@@ -22,23 +22,23 @@
  * <li>A factory for the handling of URIs (resources).</li>
  * </ol>
  */
-public interface Environment
+public interface IEnvironment
 {
   /**
    * Returns a logging facility.
    */
-  public Log getLog ();
+  public ILog getLog ();
 
   /**
    * Returns a status handler.
    */
-  public StatusHandler getStatusHandler ();
+  public IStatusHandler getStatusHandler ();
 
   /**
-   * Returns a URI factory.
+   * Returns a IURI factory.
    * Hint: Implementers should insure that the Factory they return
    * has a reference to this Environment so that URI objects can
    * report progress and announce status.
    */
-  public URIFactory getURIFactory ();
+  public IURIFactory getURIFactory ();
 }
@@ -10,11 +10,11 @@
 
 /**
- * An Environment provides the means for a 
+ * An IEnvironment provides the means for a 
  * <ol>
  * <li>A log for writing messages to a logging facility,</li>
@@ -22,23 +22,23 @@
    * Hint: Implementers should insure that the Factory they return
-   * has a reference to this Environment so that URI objects can
+   * has a reference to this IEnvironment so that IURI objects can
    * report progress and announce status.
    */
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/Log.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/ILog.java
similarity index 97%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/Log.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/ILog.java
index 61920ef..50a211a 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/Log.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/ILog.java
@@ -13,9 +13,9 @@
 import org.eclipse.core.runtime.IStatus;
 
 /**
  * Log objects provide a means for logging information for FFDC etc.
  */
-public interface Log
+public interface ILog
 {
   public static final int OK = 0;
   public static final int INFO = 1;
@@ -13,9 +13,9 @@
 
 /**
- * Log objects provide a means for logging information for FFDC etc.
+ * ILog objects provide a means for logging information for FFDC etc.
  */
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URI.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURI.java
similarity index 64%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URI.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURI.java
index 65e20d3..d2694ca 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URI.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURI.java
@@ -16,35 +16,35 @@
 import java.net.URL;
 
 /**
  * A URI represents a Univeral Resource Identifer.
  */
-public interface URI
+public interface IURI
 {
   /**
    * Returns the string form of the URI.
    * The resource need not exist.
    */
   public String toString ();
 
   /**
-   * Returns the URIScheme for the scheme of this URI.
+   * Returns the IURIScheme for the scheme of this IURI.
    * The resource need not exist.
    */
-  public URIScheme getURIScheme ();
+  public IURIScheme getURIScheme ();
 
   /**
    * Returns true iff the resource identified by this URI exists.
    */
   public boolean isPresent ();
 
   /**
    * Returns true iff the resource identified by this URI exists
    * and is a leaf. Returns true always for non-hierarchical schemes.
    */
   public boolean isLeaf ();
 
   /**
    * Returns true iff the resource identified by this URI exists
    * and is readable. A readable leaf resource indicates that an
    * input stream can be opened on the resource. A readable folder
    * resource indicates that the children of the folder, if any,
@@ -53,7 +53,7 @@
   public boolean isReadable ();
 
   /**
    * Returns true iff the resource identified by this URI exists
    * and is writable. A writable leaf resource indicates that an
    * output stream can be opened on the resource. A writable folder
    * resource indicates that new resources can be created in the folder.
@@ -61,119 +61,119 @@
   public boolean isWritable ();
 
   /**
    * Returns true iff this URI belongs to a hierarchical scheme.
    * The resource need not exist.
    * this.isHierarchical() == this.getURIScheme().isHierarchical().
    */
   public boolean isHierarchical ();
 
   /**
    * Returns true iff this URI is a relative URI.
    * The resource need not exist.
    */
   public boolean isRelative ();
 
   /**
    * Returns the URI of the folder containing this URI.
    * The resource need not exist.
    */
-  public URI parent () throws URIException;
+  public IURI parent () throws URIException;
 
   /**
    * Returns a new, normalized URI formed by appending the given
    * relative URI to this URI. Both URIs must be hierarchical.
    * The resulting URI will always be hierarchical. The given
    * URI must be relative. This URI can be relative or absolute.
    * the resulting URI will be equivalently relative or absolute.
    */
-  public URI append ( URI relativeURI ) throws URIException;
+  public IURI append ( IURI relativeURI ) throws URIException;
 
   /**
    * Gets an InputStream for reading from the resource
    * identified by this leaf or non-hierarchical URI.
    */
   public InputStream getInputStream () throws URIException;
 
   /**
    * Gets an OutputStream for writing to the resource
    * identified by this leaf or non-hierarchical URI.
    */
   public OutputStream getOutputStream () throws URIException;
 
   /**
    * Creates a new, empty resource at the location identified by
    * the URI. On completion, this.isLeaf() == true. If a leaf
    * resource already exists, this method does nothing. If a
    * non-leaf resource already exists under this URI, creation
    * will fail and an exception will be thrown.
    */
   public void touchLeaf () throws URIException;
 
   /**
    * Creates a new folder resource at the location identified by
    * the URI. The scheme of the URI must be hierarchical.
    * On completion, this.isLeaf() == false. If a folder resource
    * already exists, this method does nothing. If a leaf resource
    * already exists under this URI, creation will fail and an
    * exception will be thrown.
    */
   public void touchFolder () throws URIException;
 
   /**
    * Erases the resource identified by this URI.
    */
   public void erase () throws URIException;
 
   /**
    * Renames or moves the resource identified by this URI
    * to the new URI.
    */
-  public void rename ( URI newURI ) throws URIException;
+  public void rename ( IURI newURI ) throws URIException;
 
   /**
    * Visits this resource and its decendants in pre-order fashion.
    * For each resource, whether a folder or a leaf, the given
    * URIVisitor's visit() method is called with the URI of the
    * resource. If URIVisitor.visit() returns false, the visiting
    * algorithm will "prune" the decendants of the resource and
-   * carry on visiting the rest of the tree. If URIVisitor.visit()
+   * carry on visiting the rest of the tree. If IURIVisitor.visit()
    * returns true, the visiting algorithm will continue its walk
    * down the resource's descendants.
    */
-  public void visit ( URIVisitor uriVisitor ) throws URIException;
+  public void visit ( IURIVisitor uriVisitor ) throws URIException;
 
   /**
    * As for visit(URIVisitor), except only resource URIs that are
    * accepted by the given filter are visited. If a folder resource
    * fails to be accepted by the filter, this will not prevent the
    * visiting algorithm from walking the resource's descendants.
    * It remains the job of the visitor to choose whether or not to
    * prune a branch by returning false or true.
    */
-  public void visit ( URIVisitor uriVisitor, URIFilter uriFilter ) throws URIException;
+  public void visit ( IURIVisitor uriVisitor, IURIFilter uriFilter ) throws URIException;
 
   /**
    * Returns a list of URIs for the immediate children of the given
    * hierarchical, non-leaf URI. This method never returns null,
    * though it may return a zero length array.
    */
-  public URI[] list () throws URIException;
+  public IURI[] list () throws URIException;
 
   /**
    * As for list(), except only URIs that are accepted by the given
    * filter are returned in the array. This method never returns null,
    * though it may return a zero length array.
    */
-  public URI[] list ( URIFilter uriFilter ) throws URIException;
+  public IURI[] list ( IURIFilter uriFilter ) throws URIException;
 
   /**
    * Returns true if the asURL() method is fair game,
    * in other words, if this URI can be converted into a URL.
    */
   public boolean isAvailableAsURL ();
 
   /**
    * Returns a URL object for the resource under this URI.
    * There are many URIs and URISchemes for which this method
    * will fail and throw an exception. It should be used only
    * in cases where URIs are known to be representable as URLs.
@@ -182,12 +182,12 @@
 
   /**
    * Returns true if the asFile() method is fair game,
    * in other words, if this URI can be converted into a File.
    */
   public boolean isAvailableAsFile ();
 
   /**
    * Returns a File object for the resource under this URI.
    * There are many URIs and URISchemes for which this method
    * will fail and throw an exception. It should be used only
    * in cases where URIs are known to be backed by physical files.
@@ -195,7 +195,7 @@
   public File asFile () throws URIException;
 
   /**
-   * Returns the URI as a string.
+   * Returns the IURI as a string.
    * Equivalent to toString().
    */
   public String asString ();
@@ -16,35 +16,35 @@
 
 /**
- * A URI represents a Univeral Resource Identifer.
+ * A IURI represents a Univeral Resource Identifer.
  */
@@ -16,35 +16,35 @@
 {
   /**
-   * Returns the string form of the URI.
+   * Returns the string form of the IURI.
    * The resource need not exist.
    */
@@ -16,35 +16,35 @@
 
   /**
-   * Returns true iff the resource identified by this URI exists.
+   * Returns true iff the resource identified by this IURI exists.
    */
   public boolean isPresent ();
@@ -16,35 +16,35 @@
 
   /**
-   * Returns true iff the resource identified by this URI exists
+   * Returns true iff the resource identified by this IURI exists
    * and is a leaf. Returns true always for non-hierarchical schemes.
    */
@@ -16,35 +16,35 @@
 
   /**
-   * Returns true iff the resource identified by this URI exists
+   * Returns true iff the resource identified by this IURI exists
    * and is readable. A readable leaf resource indicates that an
    * input stream can be opened on the resource. A readable folder
@@ -53,7 +53,7 @@
 
   /**
-   * Returns true iff the resource identified by this URI exists
+   * Returns true iff the resource identified by this IURI exists
    * and is writable. A writable leaf resource indicates that an
    * output stream can be opened on the resource. A writable folder
@@ -61,119 +61,119 @@
 
   /**
-   * Returns true iff this URI belongs to a hierarchical scheme.
+   * Returns true iff this IURI belongs to a hierarchical scheme.
    * The resource need not exist.
    * this.isHierarchical() == this.getURIScheme().isHierarchical().
@@ -61,119 +61,119 @@
 
   /**
-   * Returns true iff this URI is a relative URI.
+   * Returns true iff this IURI is a relative IURI.
    * The resource need not exist.
    */
@@ -61,119 +61,119 @@
 
   /**
-   * Returns the URI of the folder containing this URI.
+   * Returns the IURI of the folder containing this IURI.
    * The resource need not exist.
    */
@@ -61,119 +61,119 @@
 
   /**
-   * Returns a new, normalized URI formed by appending the given
-   * relative URI to this URI. Both URIs must be hierarchical.
-   * The resulting URI will always be hierarchical. The given
-   * URI must be relative. This URI can be relative or absolute.
-   * the resulting URI will be equivalently relative or absolute.
+   * Returns a new, normalized IURI formed by appending the given
+   * relative IURI to this IURI. Both URIs must be hierarchical.
+   * The resulting IURI will always be hierarchical. The given
+   * IURI must be relative. This IURI can be relative or absolute.
+   * the resulting IURI will be equivalently relative or absolute.
    */
@@ -61,119 +61,119 @@
   /**
    * Gets an InputStream for reading from the resource
-   * identified by this leaf or non-hierarchical URI.
+   * identified by this leaf or non-hierarchical IURI.
    */
   public InputStream getInputStream () throws URIException;
@@ -61,119 +61,119 @@
   /**
    * Gets an OutputStream for writing to the resource
-   * identified by this leaf or non-hierarchical URI.
+   * identified by this leaf or non-hierarchical IURI.
    */
   public OutputStream getOutputStream () throws URIException;
@@ -61,119 +61,119 @@
   /**
    * Creates a new, empty resource at the location identified by
-   * the URI. On completion, this.isLeaf() == true. If a leaf
+   * the IURI. On completion, this.isLeaf() == true. If a leaf
    * resource already exists, this method does nothing. If a
@@ -61,119 +61,119 @@
    * resource already exists, this method does nothing. If a
-   * non-leaf resource already exists under this URI, creation
+   * non-leaf resource already exists under this IURI, creation
    * will fail and an exception will be thrown.
    */
@@ -61,119 +61,119 @@
   /**
    * Creates a new folder resource at the location identified by
-   * the URI. The scheme of the URI must be hierarchical.
+   * the IURI. The scheme of the IURI must be hierarchical.
    * On completion, this.isLeaf() == false. If a folder resource
    * already exists, this method does nothing. If a leaf resource
@@ -61,119 +61,119 @@
    * On completion, this.isLeaf() == false. If a folder resource
    * already exists, this method does nothing. If a leaf resource
-   * already exists under this URI, creation will fail and an
+   * already exists under this IURI, creation will fail and an
    * exception will be thrown.
    */
@@ -61,119 +61,119 @@
 
   /**
-   * Erases the resource identified by this URI.
+   * Erases the resource identified by this IURI.
    */
   public void erase () throws URIException;
@@ -61,119 +61,119 @@
 
   /**
-   * Renames or moves the resource identified by this URI
-   * to the new URI.
+   * Renames or moves the resource identified by this IURI
+   * to the new IURI.
    */
@@ -61,119 +61,119 @@
    * Visits this resource and its decendants in pre-order fashion.
    * For each resource, whether a folder or a leaf, the given
-   * URIVisitor's visit() method is called with the URI of the
-   * resource. If URIVisitor.visit() returns false, the visiting
+   * IURIVisitor's visit() method is called with the IURI of the
+   * resource. If IURIVisitor.visit() returns false, the visiting
    * algorithm will "prune" the decendants of the resource and
@@ -61,119 +61,119 @@
 
   /**
-   * As for visit(URIVisitor), except only resource URIs that are
+   * As for visit(IURIVisitor), except only resource URIs that are
    * accepted by the given filter are visited. If a folder resource
    * fails to be accepted by the filter, this will not prevent the
@@ -61,119 +61,119 @@
   /**
    * Returns a list of URIs for the immediate children of the given
-   * hierarchical, non-leaf URI. This method never returns null,
+   * hierarchical, non-leaf IURI. This method never returns null,
    * though it may return a zero length array.
    */
@@ -61,119 +61,119 @@
   /**
    * Returns true if the asURL() method is fair game,
-   * in other words, if this URI can be converted into a URL.
+   * in other words, if this IURI can be converted into a URL.
    */
   public boolean isAvailableAsURL ();
@@ -61,119 +61,119 @@
 
   /**
-   * Returns a URL object for the resource under this URI.
+   * Returns a URL object for the resource under this IURI.
    * There are many URIs and URISchemes for which this method
    * will fail and throw an exception. It should be used only
@@ -182,12 +182,12 @@
   /**
    * Returns true if the asFile() method is fair game,
-   * in other words, if this URI can be converted into a File.
+   * in other words, if this IURI can be converted into a File.
    */
   public boolean isAvailableAsFile ();
@@ -182,12 +182,12 @@
 
   /**
-   * Returns a File object for the resource under this URI.
+   * Returns a File object for the resource under this IURI.
    * There are many URIs and URISchemes for which this method
    * will fail and throw an exception. It should be used only
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIFactory.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIFactory.java
similarity index 60%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIFactory.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIFactory.java
index 9943b15..011c2c5 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIFactory.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIFactory.java
@@ -13,27 +13,27 @@
 import java.net.URL;
 
 /**
  * This is a factory for creating new URI and URIScheme objects.
  */
-public interface URIFactory
+public interface IURIFactory
 {
   /**
    * Creates and returns a new URI for the given string.
    */
-  public URI newURI ( String uri ) throws URIException;
+  public IURI newURI ( String uri ) throws URIException;
 
   /**
    * Creates and returns a new URI for the given URL.
    */
-  public URI newURI ( URL url ) throws URIException;
+  public IURI newURI ( URL url ) throws URIException;
 
   /**
    * Creates and returns a new URIScheme for the given scheme string.
    * If the string contains no colons, the entire string is interpretted
    * as the name of the scheme. If the string contains a colon, then the
    * substring up to but excluding the first colon is interpretted as the
    * name of the scheme, meaning the caller can pass in any URI string in
    * order to get a URIScheme object.
    */
-  public URIScheme newURIScheme ( String schemeOrURI ) throws URIException;
+  public IURIScheme newURIScheme ( String schemeOrURI ) throws URIException;
 }
@@ -13,27 +13,27 @@
 
 /**
- * This is a factory for creating new URI and URIScheme objects.
+ * This is a factory for creating new IURI and IURIScheme objects.
  */
@@ -13,27 +13,27 @@
 {
   /**
-   * Creates and returns a new URI for the given string.
+   * Creates and returns a new IURI for the given string.
    */
@@ -13,27 +13,27 @@
 
   /**
-   * Creates and returns a new URI for the given URL.
+   * Creates and returns a new IURI for the given URL.
    */
@@ -13,27 +13,27 @@
 
   /**
-   * Creates and returns a new URIScheme for the given scheme string.
+   * Creates and returns a new IURIScheme for the given scheme string.
    * If the string contains no colons, the entire string is interpretted
    * as the name of the scheme. If the string contains a colon, then the
@@ -13,27 +13,27 @@
    * as the name of the scheme. If the string contains a colon, then the
    * substring up to but excluding the first colon is interpretted as the
-   * name of the scheme, meaning the caller can pass in any URI string in
-   * order to get a URIScheme object.
+   * name of the scheme, meaning the caller can pass in any IURI string in
+   * order to get a IURIScheme object.
    */
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIFilter.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIFilter.java
similarity index 85%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIFilter.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIFilter.java
index 5937a60..f029330 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIFilter.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIFilter.java
@@ -12,16 +12,16 @@
 
 /**
  * This interface is implemented by classes that visit or list URIs.
- * Refer to {@link URI#getChildren}.
+ * Refer to {@link IURI#getChildren}.
  */
-public interface URIFilter
+public interface IURIFilter
 {
   /**
    * Filters the given URI.
    * @param uri The resource to filter.
    * @return True if the resource matches the filter,
    * false if it does not.
    * @throws URIException If the filter fails to analyze the resource.
    */
-  public boolean accepts ( URI uri ) throws URIException;
+  public boolean accepts ( IURI uri ) throws URIException;
 }
@@ -12,16 +12,16 @@
 {
   /**
-   * Filters the given URI.
+   * Filters the given IURI.
    * @param uri The resource to filter.
    * @return True if the resource matches the filter,
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIScheme.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIScheme.java
similarity index 70%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIScheme.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIScheme.java
index e9ba5e9..52e1258 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIScheme.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIScheme.java
@@ -14,26 +14,26 @@
 import org.eclipse.core.runtime.IStatus;
 
 /**
  * A URIScheme represents a single scheme for some a family of
  * Univeral Resource Identifiers. Examples include "file", "http"
  * and "platform" (Eclipse).
  */
-public interface URIScheme
+public interface IURIScheme
 {
   /**
-   * Returns a new URI.
+   * Returns a new IURI.
    */
-  public URI newURI ( String uri ) throws URIException;
+  public IURI newURI ( String uri ) throws URIException;
 
   /**
-   * Returns a new URI.
+   * Returns a new IURI.
    */
-  public URI newURI ( URL url ) throws URIException;
+  public IURI newURI ( URL url ) throws URIException;
 
   /**
-   * Returns a new URI.
+   * Returns a new IURI.
    */
-  public URI newURI ( URI uri ) throws URIException;
+  public IURI newURI ( IURI uri ) throws URIException;
 
   /**
    * Returns the proper name of the scheme.
@@ -46,17 +46,17 @@
   public boolean isHierarchical ();
 
   /**
    * Returns true if and only if the given URI satisfies the
    * grammatical requirements of the scheme. Absolute URIs must
    * begin with "<scheme>:". Relative URIs must either not contain
    * a colon, ":", or it must begin with "./".
    */
-  public boolean isValid ( URI uri );
+  public boolean isValid ( IURI uri );
 
   /**
    * Returns a Status object indicating whether or not the given
    * URI is valid. The severity and message of the Status object
    * will describe this.
    */
-  public IStatus validate ( URI uri );
+  public IStatus validate ( IURI uri );
 }
@@ -14,26 +14,26 @@
 
 /**
- * A URIScheme represents a single scheme for some a family of
+ * A IURIScheme represents a single scheme for some a family of
  * Univeral Resource Identifiers. Examples include "file", "http"
  * and "platform" (Eclipse).
@@ -46,17 +46,17 @@
 
   /**
-   * Returns true if and only if the given URI satisfies the
+   * Returns true if and only if the given IURI satisfies the
    * grammatical requirements of the scheme. Absolute URIs must
    * begin with "<scheme>:". Relative URIs must either not contain
@@ -46,17 +46,17 @@
   /**
    * Returns a Status object indicating whether or not the given
-   * URI is valid. The severity and message of the Status object
+   * IURI is valid. The severity and message of the Status object
    * will describe this.
    */
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIVisitor.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIVisitor.java
similarity index 85%
rename from plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIVisitor.java
rename to plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIVisitor.java
index 0615014..689a1b1 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIVisitor.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/IURIVisitor.java
@@ -12,16 +12,16 @@
 
 /**
  * This interface is implemented by classes that visit URIs.
- * Refer to {@link URI#visit}.
+ * Refer to {@link IURI#visit}.
  */
-public interface URIVisitor
+public interface IURIVisitor
 {
   /**
    * Visits the given URI.
    * @param uri The resource to visit.
    * @return True if the resource's descendants should be visited,
    * or false if they should not be visited.
    * @throws URIException If the visit method fails.
    */
-  public boolean visit ( URI uri ) throws URIException;
+  public boolean visit ( IURI uri ) throws URIException;
 }
@@ -12,16 +12,16 @@
 {
   /**
-   * Visits the given URI.
+   * Visits the given IURI.
    * @param uri The resource to visit.
    * @return True if the resource's descendants should be visited,
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/SimpleURIFactory.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/SimpleURIFactory.java
index 0cffb72..d82e58b 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/SimpleURIFactory.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/SimpleURIFactory.java
@@ -18,33 +18,33 @@
 import org.eclipse.wst.common.internal.environment.eclipse.Messages;
 
 
-public class SimpleURIFactory implements URIFactory
+public class SimpleURIFactory implements IURIFactory
 {
   private Hashtable    schemes_ = new Hashtable();  
   
   /* (non-Javadoc)
    */
-  public URI newURI(String uri) throws URIException
+  public IURI newURI(String uri) throws URIException
   {
-    URIScheme scheme = newURIScheme( uri );
+    IURIScheme scheme = newURIScheme( uri );
     
     return scheme.newURI( uri );
   }
 
   /* (non-Javadoc)
    */
-  public URI newURI(URL url) throws URIException
+  public IURI newURI(URL url) throws URIException
   {
-    URIScheme scheme = newURIScheme( url.toString() );
+    IURIScheme scheme = newURIScheme( url.toString() );
     
     return scheme.newURI( url );
   }
 
   /* (non-Javadoc)
    */
-  public URIScheme newURIScheme(String schemeOrURI) throws URIException
+  public IURIScheme newURIScheme(String schemeOrURI) throws URIException
   {
-    URIScheme newScheme = null;
+    IURIScheme newScheme = null;
     
     if( schemeOrURI == null )
     {
@@ -57,11 +57,11 @@
     int slash    = schemeOrURI.indexOf('/');
     
     // A protocol was specified.  Note: a colon appearing after a path is not
     // considered part of the protocol for this URI.
     if( (colon != -1 && slash == -1) || ( colon != -1 && colon < slash ) )
     {
       String protocol = schemeOrURI.substring(0, colon );
-      newScheme       = (URIScheme)schemes_.get( protocol );
+      newScheme       = (IURIScheme)schemes_.get( protocol );
       
       if( newScheme == null )
       {
@@ -86,7 +86,7 @@
     return newScheme;
   }
   
-  public void registerScheme( String protocol, URIScheme scheme )
+  public void registerScheme( String protocol, IURIScheme scheme )
   {
     schemes_.put( protocol, scheme );
   }
@@ -57,11 +57,11 @@
     
     // A protocol was specified.  Note: a colon appearing after a path is not
-    // considered part of the protocol for this URI.
+    // considered part of the protocol for this IURI.
     if( (colon != -1 && slash == -1) || ( colon != -1 && colon < slash ) )
     {
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIException.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIException.java
index f4f226a..5d5b1e1 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIException.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/environment/uri/URIException.java
@@ -13,8 +13,8 @@
 import org.eclipse.core.runtime.IStatus;
 
 /**
  * This is the base class for most exceptions thrown by URI classes.
  * Every URIException carries a URI and a Status, each of which may
  * be null. The getMessage() method as inherited from Exception will
  * return the message from the URIExceptin's Status object, if any.
  */
@@ -32,10 +32,10 @@
   protected IStatus status;
 
   /**
    * The URI for which the exception occured,
    * if applicable.
    */
-  protected URI uri;
+  protected IURI uri;
 
   /**
    * Creates a new URIException with the given Status.
@@ -48,10 +48,10 @@
   }
 
   /**
    * Creates a new URIException for the given Status and URI,
    * each of which may be null.
    */
-  public URIException ( IStatus status, URI uri )
+  public URIException ( IStatus status, IURI uri )
   {
     super(status != null ? status.getMessage() : null);
     this.status = status;
@@ -67,9 +67,9 @@
   }
 
   /**
    * Returns the URI inside this exception.
    */
-  public URI getURI ()
+  public IURI getURI ()
   {
     return uri;
   }
@@ -13,8 +13,8 @@
 
 /**
- * This is the base class for most exceptions thrown by URI classes.
- * Every URIException carries a URI and a Status, each of which may
+ * This is the base class for most exceptions thrown by IURI classes.
+ * Every URIException carries a IURI and a Status, each of which may
  * be null. The getMessage() method as inherited from Exception will
  * return the message from the URIExceptin's Status object, if any.
@@ -32,10 +32,10 @@
 
   /**
-   * The URI for which the exception occured,
+   * The IURI for which the exception occured,
    * if applicable.
    */
@@ -48,10 +48,10 @@
 
   /**
-   * Creates a new URIException for the given Status and URI,
+   * Creates a new URIException for the given Status and IURI,
    * each of which may be null.
    */
@@ -67,9 +67,9 @@
 
   /**
-   * Returns the URI inside this exception.
+   * Returns the IURI inside this exception.
    */
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseLog.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseLog.java
index b5a3111..f9746a3 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseLog.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseLog.java
@@ -12,9 +12,9 @@
 
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Platform;
-import org.eclipse.wst.common.environment.Log;
+import org.eclipse.wst.common.environment.ILog;
 
-public class EclipseLog implements org.eclipse.wst.common.environment.Log 
+public class EclipseLog implements org.eclipse.wst.common.environment.ILog 
 {
 //	private Logger logger;
 	public EclipseLog() {
@@ -26,7 +26,7 @@
 	}
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#isEnabled()
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#isEnabled()
 	 */
 	public boolean isEnabled() 
   {
@@ -34,7 +34,7 @@
 	}
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#isEnabled(java.lang.String)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#isEnabled(java.lang.String)
 	 */
 	public boolean isEnabled(String option) {
 		return "true".equals(Platform.getDebugOption("org.eclipse.wst.common.environment/trace/"
@@ -42,14 +42,14 @@
 	}
 	
 	/**
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, int, java.lang.Object, java.lang.String, java.lang.Object)
 	 */
 	public void log(int severity, int messageNum, Object caller,
 			String method, Object object) {
 		
 		if (isEnabled()) {
 			switch (severity) {
-				case Log.ERROR :
+				case ILog.ERROR :
 					if (isEnabled("error"))
 //						logger
 //								.logError(getMessageNumString(messageNum) + "E "
@@ -59,7 +59,7 @@
 							+ caller + "::" + method + ": object="
 							+ object);
 					break;
-				case Log.WARNING :
+				case ILog.WARNING :
 					if (isEnabled("warning"))
 //						logger
 //								.logWarning(getMessageNumString(messageNum)
@@ -69,7 +69,7 @@
 								+ "W " + caller + "::" + method
 								+ ": object=" + object);
 					break;
-				case Log.INFO :
+				case ILog.INFO :
 					if (isEnabled("info"))
 //						logger
 //								.logInfo(getMessageNumString(messageNum) + "I "
@@ -85,7 +85,7 @@
 	}
 	
 	/**
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, int, java.lang.Object, java.lang.String, org.eclipse.wst.command.internal.provisional.env.core.common.Status)
 	 */
 	public void log(int severity, int messageNum, Object caller,
 			String method, IStatus status) {
@@ -93,7 +93,7 @@
 	}
 	
 	/**
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, int, java.lang.Object, java.lang.String, java.lang.Throwable)
 	 */
 	public void log(int severity, int messageNum, Object caller,
 			String method, Throwable throwable) {
@@ -104,19 +104,19 @@
 		/*
 		if (isEnabled()) {
 			switch (severity) {
-				case Log.ERROR :
+				case ILog.ERROR :
 					if (isEnabled("error"))
 						logger.logError(getMessageNumString(messageNum) + "E "
 								+ caller + "::" + method);
 					logger.logError(throwable);
 					break;
-				case Log.WARNING :
+				case ILog.WARNING :
 					if (isEnabled("warning"))
 						logger.logWarning(getMessageNumString(messageNum) + "W "
 								+ caller + "::" + method);
 					logger.logWarning(throwable);
 					break;
-				case Log.INFO :
+				case ILog.INFO :
 					if (isEnabled("info"))
 						logger.logInfo(getMessageNumString(messageNum) + "I "
 								+ caller + "::" + method);
@@ -128,7 +128,7 @@
 	}
 	
 	/**
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, java.lang.String, int, java.lang.Object, java.lang.String, java.lang.Object)
 	 */
 	public void log(int severity, String option, int messageNum,
 			Object caller, String method, Object object) {
@@ -143,7 +143,7 @@
 	}
 	
 	/**
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, java.lang.String, int, java.lang.Object, java.lang.String, java.lang.Throwable)
 	 */
 	public void log(int severity, String option, int messageNum,
 			Object caller, String method, Throwable throwable) {
@@ -162,7 +162,7 @@
 	}
 	
 	/**
 	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, java.lang.String, int, java.lang.Object, java.lang.String, org.eclipse.wst.command.internal.provisional.env.core.common.Status)
 	 */
 	public void log(int severity, String option, int messageNum,
 			Object caller, String method, IStatus status) {
@@ -42,14 +42,14 @@
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, int, java.lang.Object, java.lang.String, java.lang.Object)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#log(int, int, java.lang.Object, java.lang.String, java.lang.Object)
 	 */
 	public void log(int severity, int messageNum, Object caller,
@@ -85,7 +85,7 @@
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, int, java.lang.Object, java.lang.String, org.eclipse.wst.command.internal.provisional.env.core.common.Status)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#log(int, int, java.lang.Object, java.lang.String, org.eclipse.wst.command.internal.provisional.env.core.common.Status)
 	 */
 	public void log(int severity, int messageNum, Object caller,
@@ -93,7 +93,7 @@
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, int, java.lang.Object, java.lang.String, java.lang.Throwable)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#log(int, int, java.lang.Object, java.lang.String, java.lang.Throwable)
 	 */
 	public void log(int severity, int messageNum, Object caller,
@@ -128,7 +128,7 @@
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, java.lang.String, int, java.lang.Object, java.lang.String, java.lang.Object)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#log(int, java.lang.String, int, java.lang.Object, java.lang.String, java.lang.Object)
 	 */
 	public void log(int severity, String option, int messageNum,
@@ -143,7 +143,7 @@
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, java.lang.String, int, java.lang.Object, java.lang.String, java.lang.Throwable)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#log(int, java.lang.String, int, java.lang.Object, java.lang.String, java.lang.Throwable)
 	 */
 	public void log(int severity, String option, int messageNum,
@@ -162,7 +162,7 @@
 	
 	/**
-	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.Log#log(int, java.lang.String, int, java.lang.Object, java.lang.String, org.eclipse.wst.command.internal.provisional.env.core.common.Status)
+	 * @see org.eclipse.wst.command.internal.provisional.env.core.common.ILog#log(int, java.lang.String, int, java.lang.Object, java.lang.String, org.eclipse.wst.command.internal.provisional.env.core.common.Status)
 	 */
 	public void log(int severity, String option, int messageNum,
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseScheme.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseScheme.java
index 70dd627..65cb02c 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseScheme.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseScheme.java
@@ -16,18 +16,18 @@
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.osgi.util.NLS;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 import org.eclipse.wst.common.environment.uri.RelativeURI;
-import org.eclipse.wst.common.environment.uri.URI;
+import org.eclipse.wst.common.environment.uri.IURI;
 import org.eclipse.wst.common.environment.uri.URIException;
-import org.eclipse.wst.common.environment.uri.URIScheme;
+import org.eclipse.wst.common.environment.uri.IURIScheme;
 
 
-public class EclipseScheme implements URIScheme
+public class EclipseScheme implements IURIScheme
 {
-  private Environment      environment_;
+  private IEnvironment      environment_;
   
-  public EclipseScheme( Environment environment )
+  public EclipseScheme( IEnvironment environment )
   {
     environment_ = environment;
   }
@@ -41,7 +41,7 @@
 
   /**
    */
-  public boolean isValid(URI uri)
+  public boolean isValid(IURI uri)
   {
     boolean result = true;
     
@@ -61,7 +61,7 @@
 
   /**
    */
-  public URI newURI(String uri) throws URIException
+  public IURI newURI(String uri) throws URIException
   {
     String newURI = null;
     
@@ -96,21 +96,21 @@
 
   /**
    */
-  public URI newURI(URI uri) throws URIException
+  public IURI newURI(IURI uri) throws URIException
   {
     return newURI( uri.toString() );
   }
 
   /**
    */
-  public URI newURI(URL url) throws URIException
+  public IURI newURI(URL url) throws URIException
   {
     return newURI( url.toString() );
   }
 
   /**
    */
-  public IStatus validate(URI uri)
+  public IStatus validate(IURI uri)
   {
     IStatus status = null;
     
@@ -172,7 +172,7 @@
   /**
    * 
    * @param absolutePath an absolute IPath
    * @return returns the platform URI for this path.
    */
   public String getURLFromPath( IPath absolutePath )
   {
@@ -172,7 +172,7 @@
    * 
    * @param absolutePath an absolute IPath
-   * @return returns the platform URI for this path.
+   * @return returns the platform IURI for this path.
    */
   public String getURLFromPath( IPath absolutePath )
diff --git a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseURI.java b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseURI.java
index 836eb61..51f24f8 100644
--- a/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseURI.java
+++ b/plugins/org.eclipse.wst.common.environment/src/org/eclipse/wst/common/internal/environment/eclipse/EclipseURI.java
@@ -25,21 +25,21 @@
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.osgi.util.NLS;
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 import org.eclipse.wst.common.environment.uri.RelativeURI;
-import org.eclipse.wst.common.environment.uri.URI;
+import org.eclipse.wst.common.environment.uri.IURI;
 import org.eclipse.wst.common.environment.uri.URIException;
-import org.eclipse.wst.common.environment.uri.URIFilter;
-import org.eclipse.wst.common.environment.uri.URIScheme;
+import org.eclipse.wst.common.environment.uri.IURIFilter;
+import org.eclipse.wst.common.environment.uri.IURIScheme;
 
 
 public class EclipseURI extends RelativeURI
 {
-  private Environment      environment_;
+  private IEnvironment      environment_;
   private EclipseScheme    scheme_;
   private File             file_;
   
-  public EclipseURI( String uri, Environment environment )
+  public EclipseURI( String uri, IEnvironment environment )
   {
     super( uri );
     
@@ -49,7 +49,7 @@
   }
     
   /**
-   * @see org.eclipse.env.uri.URI#erase()
+   * @see org.eclipse.env.uri.IURI#erase()
    */
   public void erase() throws URIException
   {
@@ -79,7 +79,7 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#getInputStream()
+   * @see org.eclipse.env.uri.IURI#getInputStream()
    */
   public InputStream getInputStream() throws URIException
   {
@@ -104,12 +104,12 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#getOutputStream()
+   * @see org.eclipse.env.uri.IURI#getOutputStream()
    */
   public OutputStream getOutputStream() throws URIException
   {
     // Ensure that the parent folder exists.
-    URI parent = parent();
+    IURI parent = parent();
     
     if( !parent.isPresent() )
     {
@@ -120,15 +120,15 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#getURIScheme()
+   * @see org.eclipse.env.uri.IURI#getURIScheme()
    */
-  public URIScheme getURIScheme()
+  public IURIScheme getURIScheme()
   {
     return scheme_;
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#isLeaf()
+   * @see org.eclipse.env.uri.IURI#isLeaf()
    */
   public boolean isLeaf()
   {
@@ -147,7 +147,7 @@
     }
     catch( URIException exc )
     {
       // This URI does not exist.
       result = false;
     }
    
@@ -155,7 +155,7 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#isPresent()
+   * @see org.eclipse.env.uri.IURI#isPresent()
    */
   public boolean isPresent()
   {
@@ -172,7 +172,7 @@
     }
     catch( URIException exc )
     {
       // This URI does not exist.
       result = false;
     }
     
@@ -180,7 +180,7 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#isReadable()
+   * @see org.eclipse.env.uri.IURI#isReadable()
    */
   public boolean isReadable()
   {
@@ -197,7 +197,7 @@
     }
     catch( URIException exc )
     {
       // This URI does not exist.
       result = false;
     }
     
@@ -205,7 +205,7 @@
    }
 
   /**
-   * @see org.eclipse.env.uri.URI#isRelative()
+   * @see org.eclipse.env.uri.IURI#isRelative()
    */
   public boolean isRelative()
   { 
@@ -213,7 +213,7 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#isWritable()
+   * @see org.eclipse.env.uri.IURI#isWritable()
    */
   public boolean isWritable()
   {
@@ -232,7 +232,7 @@
     }
     catch( URIException exc )
     {
       // This URI does not exist.
       result = false;
     }
     
@@ -240,12 +240,12 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#list()
+   * @see org.eclipse.env.uri.IURI#list()
    */
-  public URI[] list() throws URIException
+  public IURI[] list() throws URIException
   {
     IResource resource    = getResource();
-    URI[]     uriChildren = new URI[0];
+    IURI[]     uriChildren = new IURI[0];
     
     if( resource.getType() == IResource.FOLDER )
     {
@@ -255,7 +255,7 @@
       {
         IResource[] children    = folder.members();  
   
-        uriChildren = new URI[children.length];
+        uriChildren = new IURI[children.length];
         
         for( int index = 0; index < children.length; index++ )
         {
@@ -272,12 +272,12 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#list(org.eclipse.env.uri.URIFilter)
+   * @see org.eclipse.env.uri.IURI#list(org.eclipse.env.uri.IURIFilter)
    */
-  public URI[] list(URIFilter uriFilter) throws URIException
+  public IURI[] list(IURIFilter uriFilter) throws URIException
   {
     IResource resource = getResource();
-    URI[]     result   = new URI[0];
+    IURI[]     result   = new IURI[0];
     
     if( resource.getType() == IResource.FOLDER )
      {
@@ -291,7 +291,7 @@
         for( int index = 0; index < children.length; index++ )
          {
           IPath path = children[index].getFullPath();
-          URI   uri  = new EclipseURI( scheme_.getURLFromPath(path), environment_ );
+          IURI   uri  = new EclipseURI( scheme_.getURLFromPath(path), environment_ );
           
           if( uriFilter.accepts( uri ) )
           {
@@ -299,7 +299,7 @@
           }
         }
         
-        result = (URI[])uriChildren.toArray( new URI[0] );
+        result = (IURI[])uriChildren.toArray( new IURI[0] );
       }
       catch( CoreException exc )
       {
@@ -310,16 +310,16 @@
   }
    
   /**
-   * @see org.eclipse.env.uri.URI#rename(org.eclipse.env.uri.URI)
+   * @see org.eclipse.env.uri.IURI#rename(org.eclipse.env.uri.IURI)
    */
-  public void rename(URI newURI )
+  public void rename(IURI newURI )
   {
     // TODO Auto-generated method stub
 
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#touchFolder()
+   * @see org.eclipse.env.uri.IURI#touchFolder()
    */
   public void touchFolder() throws URIException
   {
@@ -349,7 +349,7 @@
       }
       else
       {
          //??? Not sure what to do if touching a folder and the URI exists and it is not a folder.
       }
     }
     else
@@ -369,7 +369,7 @@
   }
 
   /**
-   * @see org.eclipse.env.uri.URI#touchLeaf()
+   * @see org.eclipse.env.uri.IURI#touchLeaf()
    */
   public void touchLeaf() throws URIException
   {
@@ -382,7 +382,7 @@
     else
     {
       // Get the parent for this leaf and create it if required.
-      URI parent = parent();
+      IURI parent = parent();
       
       if( !parent.isPresent() )
       {  
@@ -412,7 +412,7 @@
   }
   
   /**
-   * @see org.eclipse.env.uri.URI#getOutputStream()
+   * @see org.eclipse.env.uri.IURI#getOutputStream()
    */
   private OutputStream getOutStream() throws URIException
   {
@@ -425,7 +425,7 @@
   }
   
   /**
    * Returns a File object for the resource under this URI.
    * There are many URIs and URISchemes for which this method
    * will fail and throw an exception. It should be used only
    * in cases where URIs are known to be backed by physical files.
@@ -147,7 +147,7 @@
     catch( URIException exc )
     {
-      // This URI does not exist.
+      // This IURI does not exist.
       result = false;
     }
@@ -172,7 +172,7 @@
     catch( URIException exc )
     {
-      // This URI does not exist.
+      // This IURI does not exist.
       result = false;
     }
@@ -197,7 +197,7 @@
     catch( URIException exc )
     {
-      // This URI does not exist.
+      // This IURI does not exist.
       result = false;
     }
@@ -232,7 +232,7 @@
     catch( URIException exc )
     {
-      // This URI does not exist.
+      // This IURI does not exist.
       result = false;
     }
@@ -349,7 +349,7 @@
       else
       {
-         //??? Not sure what to do if touching a folder and the URI exists and it is not a folder.
+         //??? Not sure what to do if touching a folder and the IURI exists and it is not a folder.
       }
     }
@@ -425,7 +425,7 @@
   
   /**
-   * Returns a File object for the resource under this URI.
+   * Returns a File object for the resource under this IURI.
    * There are many URIs and URISchemes for which this method
    * will fail and throw an exception. It should be used only
diff --git a/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseEnvironment.java b/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseEnvironment.java
index ae6298a..8ef0bfa 100644
--- a/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseEnvironment.java
+++ b/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseEnvironment.java
@@ -10,36 +10,36 @@
  *******************************************************************************/
 package org.eclipse.wst.common.frameworks.internal.eclipse.ui;
 
-import org.eclipse.wst.common.environment.Environment;
+import org.eclipse.wst.common.environment.IEnvironment;
 import org.eclipse.wst.common.environment.EnvironmentService;
-import org.eclipse.wst.common.environment.Log;
-import org.eclipse.wst.common.environment.StatusHandler;
+import org.eclipse.wst.common.environment.ILog;
+import org.eclipse.wst.common.environment.IStatusHandler;
 import org.eclipse.wst.common.environment.uri.SimpleURIFactory;
-import org.eclipse.wst.common.environment.uri.URIFactory;
-import org.eclipse.wst.common.environment.uri.URIScheme;
+import org.eclipse.wst.common.environment.uri.IURIFactory;
+import org.eclipse.wst.common.environment.uri.IURIScheme;
 
 
 /**
  * This class implements an Environment class for the Eclipse Environment.
  * This Environment currently supports the "platform" protocol and the "file"
  * protocol.
  *
  */
-public class EclipseEnvironment implements Environment
+public class EclipseEnvironment implements IEnvironment
 {
   private SimpleURIFactory uriFactory_      = null;
-  private StatusHandler    statusHandler_   = null;
-  private Log              logger_          = null;
+  private IStatusHandler    statusHandler_   = null;
+  private ILog              logger_          = null;
   
   public EclipseEnvironment()
   {
     this( new EclipseStatusHandler() );  
   }
   
-  public EclipseEnvironment( StatusHandler   statusHandler )
+  public EclipseEnvironment( IStatusHandler   statusHandler )
   {
-    URIScheme eclipseScheme = EnvironmentService.getEclipseScheme( this );
-    URIScheme fileScheme    = EnvironmentService.getFileScheme();
+    IURIScheme eclipseScheme = EnvironmentService.getEclipseScheme( this );
+    IURIScheme fileScheme    = EnvironmentService.getFileScheme();
     
     uriFactory_      = new SimpleURIFactory();
     statusHandler_   = statusHandler;
@@ -49,9 +49,9 @@
   }
   
   /**
-   * @see org.eclipse.wst.command.internal.provisional.env.core.common.Environment#getLog()
+   * @see org.eclipse.wst.command.internal.provisional.env.core.common.IEnvironment#getLog()
    */
-  public Log getLog()
+  public ILog getLog()
   {
 	  if( logger_ == null )
     {  
@@ -62,17 +62,17 @@
   }
    
   /**
-   * @see org.eclipse.wst.command.internal.provisional.env.core.common.Environment#getStatusHandler()
+   * @see org.eclipse.wst.command.internal.provisional.env.core.common.IEnvironment#getStatusHandler()
    */
-  public StatusHandler getStatusHandler()
+  public IStatusHandler getStatusHandler()
   {
     return statusHandler_;
   }
 
   /** (non-Javadoc)
-   * @see org.eclipse.wst.command.internal.provisional.env.core.common.Environment#getURIFactory()
+   * @see org.eclipse.wst.command.internal.provisional.env.core.common.IEnvironment#getURIFactory()
    */
-  public URIFactory getURIFactory()
+  public IURIFactory getURIFactory()
   {
     return uriFactory_;
   }
@@ -10,36 +10,36 @@
 
 /**
- * This class implements an Environment class for the Eclipse Environment.
- * This Environment currently supports the "platform" protocol and the "file"
+ * This class implements an IEnvironment class for the Eclipse IEnvironment.
+ * This IEnvironment currently supports the "platform" protocol and the "file"
  * protocol.
  *
diff --git a/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseStatusHandler.java b/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseStatusHandler.java
index 9481c52..b3e5412 100644
--- a/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseStatusHandler.java
+++ b/plugins/org.eclipse.wst.common.frameworks.ui/wtp_ui/org/eclipse/wst/common/frameworks/internal/eclipse/ui/EclipseStatusHandler.java
@@ -15,15 +15,15 @@
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.wst.common.environment.Choice;
 import org.eclipse.wst.common.environment.StatusException;
-import org.eclipse.wst.common.environment.StatusHandler;
+import org.eclipse.wst.common.environment.IStatusHandler;
 import org.eclipse.wst.common.frameworks.internal.dialog.ui.MessageDialog;
 import org.eclipse.wst.common.frameworks.internal.dialog.ui.StatusDialogConstants;
 
 
 /**
  * This is the Eclipse UI version of the StatusHandler
  */
-public class EclipseStatusHandler implements StatusHandler
+public class EclipseStatusHandler implements IStatusHandler
 {
   private Shell        shell_;
   
@@ -38,7 +38,7 @@
   }
   
   /**
-   * @see org.eclipse.env.common.StatusHandler#report(org.eclipse.env.common.Status, org.eclipse.env.common.Choice[])
+   * @see org.eclipse.env.common.IStatusHandler#report(org.eclipse.env.common.Status, org.eclipse.env.common.Choice[])
    */
   public Choice report(IStatus status, Choice[] choices) 
   {
@@ -59,7 +59,7 @@
   }
 
   /**
-   * @see org.eclipse.env.common.StatusHandler#report(org.eclipse.env.common.Status)
+   * @see org.eclipse.env.common.IStatusHandler#report(org.eclipse.env.common.Status)
    */
   public void report(IStatus status) throws StatusException
   {
@@ -112,7 +112,7 @@
   }
   
   /**
-   * @see org.eclipse.wst.command.internal.provisional.env.core.common.StatusHandler#reportError(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
+   * @see org.eclipse.wst.command.internal.provisional.env.core.common.IStatusHandler#reportError(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
    */
   public void reportError(IStatus status)
   {
@@ -120,7 +120,7 @@
   }
   
   /**
-   * @see org.eclipse.wst.command.internal.provisional.env.core.common.StatusHandler#reportInfo(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
+   * @see org.eclipse.wst.command.internal.provisional.env.core.common.IStatusHandler#reportInfo(org.eclipse.wst.command.internal.provisional.env.core.common.Status)
    */
   public void reportInfo(IStatus status)
   {
@@ -15,15 +15,15 @@
 
 /**
- * This is the Eclipse UI version of the StatusHandler
+ * This is the Eclipse UI version of the IStatusHandler
  */